#
# Copyright (c) 2015-2020 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

"""PyAMS_*** module

"""

__docformat__ = 'restructuredtext'

from pyramid.events import subscriber

from pyams_content.component.theme import IThemesManager, IThemesManagerTarget
from pyams_form.interfaces.form import IFormWidgetsUpdatedEvent
from pyams_portal.zmi.portlet import PortletRendererPropertiesEditForm
from pyams_utils.traversing import get_parent


@subscriber(IFormWidgetsUpdatedEvent, context_selector=PortletRendererPropertiesEditForm)
def handle_head_filter_search_results_portlet_settings_form(event):
    """Handle head filter search results portlet settings form"""
    form = event.object
    renderer_name = form.context.renderer
    if renderer_name != 'head-filters':
        return
    themes_target = get_parent(form.context, IThemesManagerTarget)
    if themes_target is not None:
        themes_manager = IThemesManager(themes_target)
        filter_1 = form.widgets.get('themes_filter_1')
        if filter_1 is not None:
            filter_1.thesaurus_name = themes_manager.thesaurus_name
            filter_1.extract_name = themes_manager.extract_name
        filter_2 = form.widgets.get('themes_filter_2')
        if filter_2 is not None:
            filter_2.thesaurus_name = themes_manager.thesaurus_name
            filter_2.extract_name = themes_manager.extract_name
