(function($, globals) {

	'use strict';

	var ams = globals.MyAMS;

	globals.ONF = {

		/**
		 * Search engines management
		 */
		search: {

			updateSort: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var index = $(this).data('ams-sort-index');
					$('input[name="order_by"]', form).val(index);
					form.submit();
				}
			},

			updatePageLength: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var length = $(this).val();
					$('input[name="start"]', form).val(0);
					$('input[name="length"]', form).val(length);
					form.submit();
				}
			},

			previousPage: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var current = $(this).parents('ol.pagination').data('ams-current-page');
					var length = $('input[name="length"]', form).val();
					$('input[name="start"]', form).val(length * (current - 2));
					form.submit();
				}
			},

			nextPage: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var current = $(this).parents('ol.pagination').data('ams-current-page');
					var length = $('input[name="length"]', form).val();
					$('input[name="start"]', form).val(length * current);
					form.submit();
				}
			},

			gotoPage: function() {
				var form = $('form[id="recherche-results"]');
				if (form.exists()) {
					var target = parseInt($(this).text());
					var length = $('input[name="length"]', form).val();
					$('input[name="start"]', form).val(length * (target - 1));
					form.submit();
				}
			}
		},

		/**
		 * Forms management
		 */
		form: {

			autoSubmit: function(evt) {
				$(evt.target).parents('form').submit();
			},

			resetAndSubmit: function(evt) {
				var form = $(evt.target).parents('form');
				$('input[type="text"]', form).each(function(idx, elt) {
					$(elt).val('');
				});
				$('.select2', form).each(function(idx, elt) {
					$(elt).select2('val', null);
				});
				form.submit();
			},

			submitHandler: function(form, event) {

				function doSubmit(form) {
					var button = $('button[type="submit"]', form),
						name = button.attr('name'),
						input = $('input[name="' + name + '"]', form);
					if (!input.exists()) {
						$('<input />').attr('type', 'hidden')
									  .attr('name', name)
									  .attr('value', button.attr('value'))
									  .appendTo(form);
					}
					form.submit();
				}

				if (window.grecaptcha) {  // check if recaptcha was loaded
					var captcha_key = $(form).data('ams-form-captcha-key');
					grecaptcha.execute(captcha_key, {action: 'form_submit'}).then(function(token) {
						$('.state-error', form).removeClass('state-error');
						$('input[name="g-recaptcha-response"]', form).val(token);
						doSubmit(form);
					});
				} else {
					doSubmit(form);
				}
			}
		}
	};

	/**
	 * Update main menus status
	 */
	$('.main-nav__link', '#menu-principal').each(function() {
		if (window.location.href.startsWith($(this).attr('data-ams-url') || '##')) {
			$(this).parents('li').first().addClass('main-nav__item--current');
		}
	});

	/**
	 * Update all external links target
	 */
	var base = window.location.protocol + '//' + window.location.host;
	$('a[href]').each(function() {
		var href = $(this).attr('href');
		if (!(href.startsWith('/') ||
			  href.startsWith('#') ||
			  href.startsWith('javascript:') ||
			  href.startsWith('mailto:') ||
			  href.startsWith(base))) {
			$(this).attr('target', '_blank');
		}
	});

	/**
	 * Update SVG images
	 */
	var svgs = $('.svg-container');
	if (svgs.length > 0) {
		svgs.each(function() {
			var container = $(this);
			var svg = $('svg', container),
				width = svg.attr('width'),
				height = svg.attr('height');
			if (width && height) {
				svg.get(0).setAttribute('viewBox',
										'0 0 ' + Math.round(parseFloat(width)) + ' ' +
												 Math.round(parseFloat(height)));
			}
			svg.attr('width', '100%')
			   .attr('height', 'auto')
			   .removeAttr('preserveAspectRatio');
		})
	}

	/**
	 * Home page video player button
	 */
	var videoBg = $('#homebannerVideoBg');
	if (videoBg.length > 0) {
		var button = $('#videoBgButton');
		var buttonText = $('#videoBgButtonTxt');

		button.on('click', function (e) {
			if (buttonText.hasClass('playing')) {
				videoBg.get(0).pause();
				button.removeClass('homebanner__videoBtn--paused');
				buttonText.removeClass('playing')
						  .text(buttonText.data('onf-play-text'));
			} else {
				videoBg.get(0).play();
				button.addClass('homebanner__videoBtn--paused');
				buttonText.addClass('playing')
						  .text(buttonText.data('onf-stop-text'));
			}
		});
	}


	// Videos sources updates
	//
	// Update videos sources based on current screen resolution
	function resetVideosSources() {
		var videos = $('video');
		if (videos.length > 0) {
			var width;
			if (window.matchMedia === undefined) {
				width = (window.innerWidth > 0) ? window.innerWidth : screen.width
			}
			videos.each(function(idx, elt) {
				var video = $(elt),
					position = elt.currentTime || 0,
					sources = video.data('ams-sources'),
					loaded = {};
				if (sources) {
					video.empty();
					for (var idxSrc in sources) {
						if (!sources.hasOwnProperty(idxSrc)) {
							continue;
						}
						var source = sources[idxSrc],
							type = source.type,
							condition;
						if (loaded[type] !== undefined) {
							continue;
						}
						if (window.matchMedia === undefined) {
							condition = (source.min < width);
							if (condition && source.max) {
								condition = (width <= source.max);
							}
						} else {
							var min = source.min ? '(min-device-width: ' + source.min + 'px)' : '',
								max = source.max ? '(max-device-width: ' + source.max + 'px)' : '',
								query = min + ((min && max) ? ' and ' : '') + max;
							condition = window.matchMedia(query).matches;
						}
						if (condition) {
							$('<source>').attr('type', type)
								.attr('src', source.src)
								.appendTo(video);
							loaded[type] = true;
						}
					}
					elt.currentTime = position;
				}
			});
		}
	}
	resetVideosSources();
	window.addEventListener('resize', resetVideosSources);


	// Initialize main events handlers
	MyAMS.initHandlers(document);


	// Download custom MyAMS modules to handle forms
	var forms = $('form.ams-form', document);
	if (forms.exists()) {
		ams.require(['error', 'ajax', 'form', 'plugins-loader', 'helpers', 'i18n'], function () {
			var required = ['plugins'];
			var html = $('html');
			var lang = html.attr('lang') || html.attr('xml:lang');
			if (lang && !lang.startsWith('en')) {
				ams.lang = lang;
				required.push(ams.baseURL + 'i18n/myams_' + lang.substr(0, 2) + ams.devext + '.js');
			}
			ams.require(required, function() {
				ams.getCSS('/--static--/pyams_default_theme/css/select2.css', 'pyams_select2', function () {
					ams.plugins.initData(document);
					ams.form.init(document);
					ams.plugins.init(document);
				});
			});
		});
	}

})(jQuery, this);
